#' Retrieve protein-coding genes
#'
#' This function uses ensembldb and current ccds release of human genome
#'  to retrieve a current catalog of protein-coding gene names and ids
#'
#' @param generate.rdata instead of returning a list of gene sets, it saves them to disk
#'
#' @return a list of gene names and ids
#' Gene names:
#'
#' - `all.genes`: Union of genes from `ensembldb` and `ccds`
#' - `ensembl.genes`: Protein coding genes from `ensembldb`
#' - `ccds.extra.genes`: Protein coding genes from `ccds`
#'
#' Ensembl ID (ENGS****):
#'
#' - `ensg.id`: Contains the union of both protein coding genes of `ensembldb` package and `ccds` current release.
#' - _Note:_ If chunk below has warning, then not all genes ccds have an ensembl id
#'
#' @export
#'
#' @examples
#' gene.list <- retrieve.protein.coding.genes()
#' retrieve.protein.coding.genes(generate.rdata = TRUE)
retrieve.protein.coding.genes <- function(generate.rdata = FALSE) {
  futile.logger::flog.layout(futile.logger::layout.format('~m'))
  #
  edb <- EnsDb.Hsapiens.v86::EnsDb.Hsapiens.v86
  # hasProteinData(edb) # from devel only, as of 3.4
  ensembl.protein.coding <- ensembldb::genes(edb,
                                  filter = list(ensembldb::GenebiotypeFilter('protein_coding')),
                                  columns = c('gene_id', 'gene_name'))

  futile.logger::flog.info('         Granges: %d', nrow(ensembl.protein.coding@elementMetadata), name = 'FUN')
  futile.logger::flog.info('Metadata columns: %d', ncol(ensembl.protein.coding@elementMetadata))

  ccds <- utils::read.table(url('ftp://ftp.ncbi.nih.gov/pub/CCDS/current_human/CCDS.current.txt'),
                     sep = '\t',
                     header = T,
                     comment.char = "|", # necessary as header line has a # character
                     stringsAsFactors = FALSE)
  futile.logger::flog.info('Size of ccds: %d x %d', nrow(ccds), ncol(ccds))

  ensembl.genes         <- sort(unique(ensembl.protein.coding@elementMetadata$gene_name))
  ensembl.genes.ensg.id <- sort(ensembl.protein.coding@elementMetadata$gene_id)

  ccds.genes       <- sort(unique(ccds$gene))
  ccds.extra.genes <- sort(ccds.genes[(!ccds.genes %in% ensembl.genes)])
  ccds.extra.genes.ensg.id <- ensembldb::genes(edb,
                                               filter = list(ensembldb::GenenameFilter(ccds.extra.genes)),
                                               columns = c('gene_id', 'gene_name'))

  #
  ensg.id <- sort(unique(c(ensembl.protein.coding@elementMetadata$gene_id, ensembl.genes.ensg.id)))

  #
  all.genes <- sort(unique(c(ensembl.genes, ccds.extra.genes)))

  if (length(unique(ccds.extra.genes.ensg.id@elementMetadata$gene_id)) != length(ccds.extra.genes)) {
    futile.logger::flog.warn('WARNING! not all genes from ccds have a ensg id (%d have out of %d)',
              length(unique(ccds.extra.genes.ensg.id@elementMetadata$gene_id)),
              length(ccds.extra.genes))
  }

  futile.logger::flog.info('')
  futile.logger::flog.info('Unique genes from ensembldb:  % 6d', length(ensembl.genes))
  futile.logger::flog.info('      Extra genes from ccds: +% 6d', length(ccds.extra.genes))
  futile.logger::flog.info('       Overall unique genes:  % 6d', length(all.genes))
  futile.logger::flog.info('-------------------------------------------')
  futile.logger::flog.info('Head from ensembl.genes', utils::head(ensembl.genes), capture = T)
  futile.logger::flog.info('')
  futile.logger::flog.info('Head from ccds.genes (additional ones not present in ensembl)', utils::head(ccds.extra.genes), capture = T)
  futile.logger::flog.info('-------------------------------------------')
  futile.logger::flog.info('Head from ensg.id', utils::head(ensg.id), capture = T)
  futile.logger::flog.info('-------------------------------------------')
  not.ensg.id <- ccds.extra.genes[!(ccds.extra.genes %in% ccds.extra.genes.ensg.id@elementMetadata$gene_name)]
  futile.logger::flog.info('CCDS genes that don\'t have an ENSG** id: %d', length(not.ensg.id))
  futile.logger::flog.info('', not.ensg.id, capture = T)

  if (generate.rdata) {
    save(all.genes,        file = 'all.genes.rd',        compress = 'bzip2')
    save(ensembl.genes,    file = 'ensembl.genes.rd',    compress = 'bzip2')
    save(ensg.id,          file = 'ensg.id.rd',          compress = 'bzip2')
    save(ccds.extra.genes, file = 'ccds.extra.genes.rd', compress = 'bzip2')
    futile.logger::flog.info('Created several rd data files')
    return(NULL)
  } else {
    return(list(all.genes = all.genes,
                ensembl.genes = ensembl.genes,
                ensg.id = ensg.id,
                ccds.extra.genes = ccds.extra.genes))
  }
}
